# pyog-log
Simple python logger (multithreading capable)

Installation (-U for upgrade previous version) : pip install og-log [-U]

Usage :
- from og_log import LOG,LEVEL

Init :
- LOG.start() : Init package
- LOG.level(LEVEL.xxx) : Set log level (debug,info,warning,error,fatal), default is debug

Usage :
- LOG.xxx(text) : Display text (xxx among debug,info,warning,error,fatal)


![image](https://github.com/OlivierGaland/pyog-log/assets/26048157/18067ee5-1d77-47f4-83ce-9c0f1e7d54d1)

